@@ -1,6 +1,7 @@
+import os
+
 from univention.management.console.modules.setup.netconf import SkipPhase
 from univention.management.console.modules.setup.netconf.common import AddressMap
-import os
 
 
 class PhaseRewriteWins(AddressMap):
@@ -18,7 +19,7 @@ class PhaseRewriteWins(AddressMap):
 
 	def pre(self):
 		tmp_wins = "%s.%d" % (self.filename, os.getpid())
-		with open(self.filename, "r") as read_wins:
+		with open(self.filename) as read_wins:
 			with open(tmp_wins, "w") as write_wins:
 				for line in read_wins:
 					try:
